Socket.IO support for Caelix’s Axum runtime.
This crate intentionally has no Actix dependency. It is exposed through
caelix::socket_io only when the socketio feature selects Axum.
Structs
- AckSender
- Re-exported public API. An Extractor to send an ack response corresponding to the current event. If the client sent a normal message without expecting an ack, the ack callback will do nothing.
- Data
- Re-exported public API.
An Extractor that returns the deserialized data without checking errors.
If a deserialization error occurs, the handler won’t be called
and an error log will be printed if the
tracingfeature is enabled. - Socket
Io - Re-exported public API.
The
SocketIoinstance can be cheaply cloned and moved around everywhere in your program. It can be used as the main handle to access the whole socket.io context. - Socket
IoError - Serializable failure payload used for both acknowledgement replies and the
mandatory
"error"event emitted for failed handlers. Public Caelix typeSocketIoError. - Socket
IoHandle - The Socket.IO server handle registered as a first-class Caelix provider by
caelix_axum::Application::with_socket_io. Public Caelix typeSocketIoHandle. - Socket
IoLayer - Re-exported public API.
A
LayerforSocketIoService, acting as a middleware. - Socket
Ref - Re-exported public API.
An Extractor that returns a reference to a
Socket.