Crate caelix_socketio

Crate caelix_socketio 

Socket.IO support for Caelix’s Axum runtime.

This crate intentionally has no Actix dependency. It is exposed through caelix::socket_io only when the socketio feature selects Axum.

Structs

AckSender
An Extractor to send an ack response corresponding to the current event. If the client sent a normal message without expecting an ack, the ack callback will do nothing.
Data
An Extractor that returns the deserialized data without checking errors. If a deserialization error occurs, the handler won’t be called and an error log will be printed if the tracing feature is enabled.
SocketIo
The SocketIo instance can be cheaply cloned and moved around everywhere in your program. It can be used as the main handle to access the whole socket.io context.
SocketIoError
Serializable failure payload used for both acknowledgement replies and the mandatory "error" event emitted for failed handlers.
SocketIoHandle
The Socket.IO server handle registered as a first-class Caelix provider by [caelix_axum::Application::with_socket_io].
SocketIoLayer
A Layer for SocketIoService, acting as a middleware.
SocketRef
An Extractor that returns a reference to a Socket.