pub struct AckSender<A = LocalAdapter>where
A: Adapter,{ /* private fields */ }Expand description
Re-exported public API. An Extractor to send an ack response corresponding to the current event. If the client sent a normal message without expecting an ack, the ack callback will do nothing.
It is generic over the Adapter type. If you plan to use it with another adapter than the default,
make sure to have a handler that is generic over the adapter type.
Implementations